# coding: utf-8

"""
    Mentortools Landing Page API

    Mentortools service for building and publishing landing pages

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from landing_page_server_connector.models.response_wrapper_template_get import ResponseWrapperTemplateGet  # noqa: E501

class TestResponseWrapperTemplateGet(unittest.TestCase):
    """ResponseWrapperTemplateGet unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ResponseWrapperTemplateGet:
        """Test ResponseWrapperTemplateGet
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ResponseWrapperTemplateGet`
        """
        model = ResponseWrapperTemplateGet()  # noqa: E501
        if include_optional:
            return ResponseWrapperTemplateGet(
                done = True,
                result = landing_page_server_connector.models.template_get.TemplateGet(
                    html = '', 
                    css = '', 
                    js = '', 
                    components = landing_page_server_connector.models.components.Components(), 
                    styles = [
                        None
                        ], 
                    assets = [
                        None
                        ], 
                    theme = landing_page_server_connector.models.theme.Theme(), 
                    name = '', 
                    title = '', 
                    path = '', 
                    order = 56, 
                    editor_version = null, 
                    language_id = 1, 
                    staging_html = '', 
                    staging_js = '', 
                    staging_css = '', 
                    staging_components = landing_page_server_connector.models.staging_components.Staging Components(), 
                    staging_styles = [
                        None
                        ], 
                    staging_assets = [
                        None
                        ], 
                    staging_theme = landing_page_server_connector.models.staging_theme.Staging Theme(), 
                    id = 56, 
                    is_listed = True, 
                    preview_id = '', 
                    created_at = 56, 
                    updated_at = 56, 
                    published_at = 56, 
                    deleted_at = 56, ),
                error = ''
            )
        else:
            return ResponseWrapperTemplateGet(
                done = True,
        )
        """

    def testResponseWrapperTemplateGet(self):
        """Test ResponseWrapperTemplateGet"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
